@@ -205,6 +205,7 @@ use File::Glob qw(:case);
         'FILES'        => q[cpan/Archive-Extract],
         'UPSTREAM'     => 'cpan',
         'BUGS'         => 'bug-archive-extract@rt.cpan.org',
+        'DEPRECATED'   => '5.017009',
     },
 
     'Archive::Tar' => {
@@ -307,6 +308,7 @@ use File::Glob qw(:case);
         'FILES'        => q[cpan/B-Lint],
         'EXCLUDED'     => ['t/test.pl'],
         'UPSTREAM'     => 'cpan',
+        'DEPRECATED'   => '5.017009',
     },
 
     'base' => {
@@ -324,7 +326,7 @@ use File::Glob qw(:case);
 
     'bignum' => {
         'MAINTAINER'   => 'rafl',
-        'DISTRIBUTION' => 'FLORA/bignum-0.30.tar.gz',
+        'DISTRIBUTION' => 'FLORA/bignum-0.32.tar.gz',
         'FILES'        => q[dist/bignum],
         'EXCLUDED'     => [
             qr{^inc/Module/},
@@ -397,7 +399,7 @@ use File::Glob qw(:case);
 
     'constant' => {
         'MAINTAINER'   => 'saper',
-        'DISTRIBUTION' => 'SAPER/constant-1.25.tar.gz',
+        'DISTRIBUTION' => 'SAPER/constant-1.27.tar.gz',
         'FILES'        => q[dist/constant],
         'EXCLUDED'     => [
             qw( t/00-load.t
@@ -412,7 +414,7 @@ use File::Glob qw(:case);
 
     'CPAN' => {
         'MAINTAINER'   => 'andk',
-        'DISTRIBUTION' => 'ANDK/CPAN-2.00-TRIAL.tar.gz',
+        'DISTRIBUTION' => 'ANDK/CPAN-2.00.tar.gz',
         'FILES'        => q[cpan/CPAN],
         'EXCLUDED'     => [
             qr{^distroprefs/},
@@ -479,6 +481,7 @@ use File::Glob qw(:case);
         'CUSTOMIZED' => ['Makefile.PL'],
         'UPSTREAM'   => 'cpan',
         'BUGS'       => 'bug-cpanplus@rt.cpan.org',
+        'DEPRECATED' => '5.017009',
     },
 
     'CPANPLUS::Dist::Build' => {
@@ -492,6 +495,7 @@ use File::Glob qw(:case);
                 ),
         ],
         'UPSTREAM' => 'cpan',
+        'DEPRECATED' => '5.017009',
     },
 
     'CPAN::Meta' => {
@@ -532,7 +536,7 @@ use File::Glob qw(:case);
 
     'Data::Dumper' => {
         'MAINTAINER' => 'p5p',    # Not gsar. Not ilyam. Not really smueller
-        'DISTRIBUTION' => 'SMUELLER/Data-Dumper-2.139.tar.gz',
+        'DISTRIBUTION' => 'SMUELLER/Data-Dumper-2.145.tar.gz',
         'FILES'        => q[dist/Data-Dumper],
         'UPSTREAM'     => 'blead',
     },
@@ -603,7 +607,7 @@ use File::Glob qw(:case);
 
     'Digest::SHA' => {
         'MAINTAINER'   => 'mshelor',
-        'DISTRIBUTION' => 'MSHELOR/Digest-SHA-5.82.tar.gz',
+        'DISTRIBUTION' => 'MSHELOR/Digest-SHA-5.84.tar.gz',
         'FILES'        => q[cpan/Digest-SHA],
         'EXCLUDED'     => [
             qw( t/pod.t
@@ -636,7 +640,7 @@ use File::Glob qw(:case);
 
     'Encode' => {
         'MAINTAINER'   => 'dankogai',
-        'DISTRIBUTION' => 'DANKOGAI/Encode-2.48.tar.gz',
+        'DISTRIBUTION' => 'DANKOGAI/Encode-2.49.tar.gz',
         'FILES'        => q[cpan/Encode],
         'UPSTREAM'     => 'cpan',
     },
@@ -666,7 +670,7 @@ use File::Glob qw(:case);
 
     'Env' => {
         'MAINTAINER'   => 'p5p',
-        'DISTRIBUTION' => 'FLORA/Env-1.03.tar.gz',
+        'DISTRIBUTION' => 'FLORA/Env-1.04.tar.gz',
         'FILES'        => q[dist/Env],
         'EXCLUDED'     => [qr{^t/release-.*\.t}],
         'UPSTREAM'     => 'blead',
@@ -680,7 +684,7 @@ use File::Glob qw(:case);
 
     'Exporter' => {
         'MAINTAINER'   => 'ferreira',
-        'DISTRIBUTION' => 'TODDR/Exporter-5.67.tar.gz',
+        'DISTRIBUTION' => 'TODDR/Exporter-5.68.tar.gz',
         'FILES'        => q[lib/Exporter.pm
                             lib/Exporter.t
                             lib/Exporter/Heavy.pm
@@ -747,13 +751,14 @@ use File::Glob qw(:case);
 
     'ExtUtils::MakeMaker' => {
         'MAINTAINER'   => 'mschwern',
-        'DISTRIBUTION' => 'MSCHWERN/ExtUtils-MakeMaker-6.64.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-6.66.tar.gz',
         'FILES'        => q[cpan/ExtUtils-MakeMaker],
         'EXCLUDED'     => [
             qr{^t/lib/Test/},
             qr{^(bundled|my)/},
             qr{^t/Liblist_Kid.t},
             qr{^t/liblist/},
+            qr{^\.perlcriticrc},
         ],
         'UPSTREAM' => 'first-come',
     },
@@ -775,7 +780,7 @@ use File::Glob qw(:case);
 
     'perlfaq' => {
         'MAINTAINER'   => 'perlfaq',
-        'DISTRIBUTION' => 'LLAP/perlfaq-5.0150041.tar.gz',
+        'DISTRIBUTION' => 'LLAP/perlfaq-5.0150042.tar.gz',
         'FILES'        => q[cpan/perlfaq],
         'EXCLUDED'     => [
             qw( t/release-pod-syntax.t
@@ -861,7 +866,7 @@ use File::Glob qw(:case);
 
     'File::Temp' => {
         'MAINTAINER'   => 'tjenness',
-        'DISTRIBUTION' => 'TJENNESS/File-Temp-0.22_90.tar.gz',
+        'DISTRIBUTION' => 'TJENNESS/File-Temp-0.23.tar.gz',
         'FILES'        => q[cpan/File-Temp],
         'EXCLUDED'     => [
             qw( misc/benchmark.pl
@@ -948,7 +953,7 @@ use File::Glob qw(:case);
 
     'Getopt::Long' => {
         'MAINTAINER'   => 'jv',
-        'DISTRIBUTION' => 'JV/Getopt-Long-2.38.tar.gz',
+        'DISTRIBUTION' => 'JV/Getopt-Long-2.39.tar.gz',
         'FILES'        => q[cpan/Getopt-Long],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1049,7 +1054,7 @@ use File::Glob qw(:case);
 
     'IPC::Cmd' => {
         'MAINTAINER'   => 'kane',
-        'DISTRIBUTION' => 'BINGOS/IPC-Cmd-0.78.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/IPC-Cmd-0.80.tar.gz',
         'FILES'        => q[cpan/IPC-Cmd],
         'UPSTREAM'     => 'cpan',
     },
@@ -1074,7 +1079,7 @@ use File::Glob qw(:case);
 
     'JSON::PP' => {
         'MAINTAINER'   => 'makamaka',
-        'DISTRIBUTION' => 'MAKAMAKA/JSON-PP-2.27200.tar.gz',
+        'DISTRIBUTION' => 'MAKAMAKA/JSON-PP-2.27202.tar.gz',
         'FILES'        => q[cpan/JSON-PP],
         'EXCLUDED'     => [
             't/900_pod.t',    # Pod testing
@@ -1110,7 +1115,7 @@ use File::Glob qw(:case);
 
     'Locale-Codes' => {
         'MAINTAINER'   => 'sbeck',
-        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.24.tar.gz',
+        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.25.tar.gz',
         'FILES'        => q[cpan/Locale-Codes],
         'EXCLUDED'     => [
             qw( t/pod_coverage.t
@@ -1150,6 +1155,7 @@ use File::Glob qw(:case);
         'DISTRIBUTION' => 'BINGOS/Log-Message-0.06.tar.gz',
         'FILES'        => q[cpan/Log-Message],
         'UPSTREAM'     => 'cpan',
+        'DEPRECATED'   => '5.017009',
     },
 
     'Log::Message::Simple' => {
@@ -1157,6 +1163,7 @@ use File::Glob qw(:case);
         'DISTRIBUTION' => 'BINGOS/Log-Message-Simple-0.10.tar.gz',
         'FILES'        => q[cpan/Log-Message-Simple],
         'UPSTREAM'     => 'cpan',
+        'DEPRECATED'   => '5.017009',
     },
 
     'mad' => {
@@ -1271,7 +1278,7 @@ use File::Glob qw(:case);
 
     'Module::CoreList' => {
         'MAINTAINER'   => 'bingos',
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-2.80.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-2.85.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
         'UPSTREAM'     => 'blead',
     },
@@ -1310,10 +1317,11 @@ use File::Glob qw(:case);
 
     'Module::Pluggable' => {
         'MAINTAINER'   => 'simonw',
-        'DISTRIBUTION' => 'SIMONW/Module-Pluggable-4.6.tar.gz',
+        'DISTRIBUTION' => 'SIMONW/Module-Pluggable-4.7.tar.gz',
         'FILES'        => q[cpan/Module-Pluggable],
         'UPSTREAM'     => 'cpan',
         'CUSTOMIZED'   => ['Makefile.PL'],
+        'DEPRECATED'   => '5.017009',
     },
 
     'mro' => {
@@ -1330,8 +1338,12 @@ use File::Glob qw(:case);
 
     'Net::Ping' => {
         'MAINTAINER'   => 'smpeters',
-        'DISTRIBUTION' => 'SMPETERS/Net-Ping-2.36.tar.gz',
+        'DISTRIBUTION' => 'SMPETERS/Net-Ping-2.41.tar.gz',
         'FILES'        => q[dist/Net-Ping],
+        'EXCLUDED'     => [
+            qr{^.travis.yml},
+            qr{^README.md},
+        ],
         'UPSTREAM'     => 'blead',
     },
 
@@ -1348,6 +1360,7 @@ use File::Glob qw(:case);
         'DISTRIBUTION' => 'BINGOS/Object-Accessor-0.46.tar.gz',
         'FILES'        => q[cpan/Object-Accessor],
         'UPSTREAM'     => 'cpan',
+        'DEPRECATED'   => '5.017009',
     },
 
     'ODBM_File' => {
@@ -1461,9 +1474,9 @@ use File::Glob qw(:case);
 
     'Perl::OSType' => {
         'MAINTAINER'   => 'dagolden',
-        'DISTRIBUTION' => 'DAGOLDEN/Perl-OSType-1.002.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/Perl-OSType-1.003.tar.gz',
         'FILES'        => q[cpan/Perl-OSType],
-        'EXCLUDED'     => [qr/^xt/],
+        'EXCLUDED'     => [qr/^xt/, qr{^t/00-}],
         'UPSTREAM'     => 'cpan',
     },
 
@@ -1536,6 +1549,7 @@ use File::Glob qw(:case);
         'FILES'        => q[cpan/Pod-LaTeX],
         'EXCLUDED'     => ['t/require.t'],
         'UPSTREAM'     => undef,
+        'DEPRECATED'   => '5.017008',
     },
 
     'Pod::Parser' => {
@@ -1560,7 +1574,7 @@ use File::Glob qw(:case);
 
     'Pod::Simple' => {
         'MAINTAINER'   => 'arandal',
-        'DISTRIBUTION' => 'DWHEELER/Pod-Simple-3.23.tar.gz',
+        'DISTRIBUTION' => 'DWHEELER/Pod-Simple-3.28.tar.gz',
         'FILES'        => q[cpan/Pod-Simple],
         'UPSTREAM'     => 'cpan',
     },
@@ -1574,7 +1588,7 @@ use File::Glob qw(:case);
 
     'podlators' => {
         'MAINTAINER'   => 'rra',
-        'DISTRIBUTION' => 'RRA/podlators-2.5.0.tar.gz',
+        'DISTRIBUTION' => 'RRA/podlators-2.5.1.tar.gz',
         'FILES'        => q[cpan/podlators pod/perlpodstyle.pod],
 
         # The perl distribution has pod2man.PL and pod2text.PL,  which are
@@ -1611,7 +1625,7 @@ use File::Glob qw(:case);
 
     'Safe' => {
         'MAINTAINER'   => 'rgarcia',
-        'DISTRIBUTION' => 'RGARCIA/Safe-2.33.tar.gz',
+        'DISTRIBUTION' => 'RGARCIA/Safe-2.35.tar.gz',
         'FILES'        => q[dist/Safe],
         'UPSTREAM'     => 'blead',
     },
@@ -1746,6 +1760,7 @@ use File::Glob qw(:case);
         'DISTRIBUTION' => 'BINGOS/Term-UI-0.34.tar.gz',
         'FILES'        => q[cpan/Term-UI],
         'UPSTREAM'     => 'cpan',
+        'DEPRECATED'   => '5.017009',
     },
 
     'Test' => {
@@ -1827,7 +1842,7 @@ use File::Glob qw(:case);
 
     'Text::ParseWords' => {
         'MAINTAINER'   => 'chorny',
-        'DISTRIBUTION' => 'CHORNY/Text-ParseWords-3.27.zip',
+        'DISTRIBUTION' => 'CHORNY/Text-ParseWords-3.28.tar.gz',
         'FILES'        => q[cpan/Text-ParseWords],
         'EXCLUDED'     => ['t/pod.t'],
 
@@ -2023,7 +2038,7 @@ use File::Glob qw(:case);
 
     'version' => {
         'MAINTAINER'   => 'jpeacock',
-        'DISTRIBUTION' => 'JPEACOCK/version-0.9901.tar.gz',
+        'DISTRIBUTION' => 'JPEACOCK/version-0.9902.tar.gz',
         'FILES'        => q[lib/version.pm lib/version.pod lib/version],
         'EXCLUDED' => [
             qr{^t/.*\.t$},
@@ -2075,7 +2090,7 @@ use File::Glob qw(:case);
 
     'Win32' => {
         'MAINTAINER'   => 'jand',
-        'DISTRIBUTION' => "JDB/Win32-0.46.tar.gz",
+        'DISTRIBUTION' => "JDB/Win32-0.47.tar.gz",
         'FILES'        => q[cpan/Win32],
         'UPSTREAM'     => 'cpan',
     },
