@@ -1,6 +1,7 @@
 package B::Lint::Debug;
+use if $] > 5.017, 'deprecate';
 
-our $VERSION = '0.01';
+our $VERSION = '1.17';
 
 =head1 NAME
 
@@ -13,13 +14,15 @@ should not be loaded unless you're debugging.
 
 =cut
 
-package B::SPECIAL;
+package # hide from PAUSE
+    B::SPECIAL;
 use overload '""' => sub {
     my $self = shift @_;
     "SPECIAL($$self)";
 };
 
-package B::OP;
+package # hide from PAUSE
+    B::OP;
 use overload '""' => sub {
     my $self  = shift @_;
     my $class = ref $self;
@@ -28,7 +31,8 @@ use overload '""' => sub {
     "$class($name)";
 };
 
-package B::SVOP;
+package # hide from PAUSE
+    B::SVOP;
 use overload '""' => sub {
     my $self  = shift @_;
     my $class = ref $self;
@@ -37,7 +41,8 @@ use overload '""' => sub {
     "$class($name," . $self->sv . "," . $self->gv . ")";
 };
 
-package B::SPECIAL;
+package # hide from PAUSE
+    B::SPECIAL;
 sub DESTROY { }
 our $AUTOLOAD;
 
@@ -45,7 +50,8 @@ sub AUTOLOAD {
     my $cx = 0;
     print "AUTOLOAD $AUTOLOAD\n";
 
-    package DB;
+    package # hide from PAUSE
+        DB;
     while ( my @stuff = caller $cx ) {
 
         print "$cx: [@DB::args] [@stuff]\n";
