@@ -6,12 +6,13 @@ afs='false'
 afsroot='/afs'
 alignbytes='4'
 aphostname='/bin/hostname'
-archlib='/usr/local/lib/perl5/5.17/unknown'
-archlibexp='/usr/local/lib/perl5/5.17/unknown'
+archlib='/usr/local/lib/perl5/5.18/unknown'
+archlibexp='/usr/local/lib/perl5/5.18/unknown'
 archname='unknown'
 asctime_r_proto='0'
 bin='/usr/local/bin'
 binexp='/usr/local/bin'
+bootstrap_charset='undef'
 byteorder='1234'
 castflags='0'
 cf_by='root@localhost'
@@ -224,7 +225,9 @@ d_inetntop='undef'
 d_inetpton='undef'
 d_int64_t='undef'
 d_ip_mreq='undef'
+d_ip_mreq_source='undef'
 d_ipv6_mreq='undef'
+d_ipv6_mreq_source='undef'
 d_isascii='undef'
 d_isblank='undef'
 d_isfinite='undef'
@@ -425,7 +428,7 @@ d_strftime='undef'
 d_strlcat='undef'
 d_strlcpy='undef'
 d_strtod='undef'
-d_strtol='undef'
+d_strtol='define'
 d_strtold='undef'
 d_strtoll='undef'
 d_strtoq='undef'
@@ -681,8 +684,8 @@ package='perl5'
 perl_static_inline='static'
 phostname='hostname'
 pidtype=int
-privlib='/usr/local/lib/perl5/5.17'
-privlibexp='/usr/local/lib/perl5/5.17'
+privlib='/usr/local/lib/perl5/5.18'
+privlibexp='/usr/local/lib/perl5/5.18'
 procselfexe=''
 prototype='undef'
 ptrsize='4'
@@ -732,11 +735,11 @@ sig_name_init='0'
 sig_num_init='0'
 sig_size='1'
 signal_t=int
-sitearch='/usr/local/lib/perl5/5.17/unknown'
-sitearchexp='/usr/local/lib/perl5/5.17/unknown'
-sitelib='/usr/local/lib/perl5/5.17'
+sitearch='/usr/local/lib/perl5/5.18/unknown'
+sitearchexp='/usr/local/lib/perl5/5.18/unknown'
+sitelib='/usr/local/lib/perl5/5.18'
 sitelib_stem='/usr/local/lib/perl5'
-sitelibexp='/usr/local/lib/perl5/5.17'
+sitelibexp='/usr/local/lib/perl5/5.18'
 sizesize=4
 sizetype='size_t'
 socksizetype='int'
